This repository contains the Conditional game data analysis package (CGDAT). It can be used to load in a csv file and filter this file based on some conditions. Further, you can filter the file based on (Player name, Time sections) and you can add a time padding to the output result.

# How to use

## Fast way
1. Download the zip.
2. Click the `installer.bat` file in the main cgdat folder.
    - The installer will install the cgdat python package and its dependencies.

## Build the program yourself
1. Open the command prompt at the main cgdat folder.
2. Run the `python setup.py build` cmd.
3. When the build is complete run the `python setup.py install` cmd.

## Use as a tool
To use the cgdat package as a GUI click the cgdat shortcut that was created in the repository folder or use the `cgdat-gui` console command. You can also create a desktop shortcut by running the `cgdat-shortcut` console command.

## Use as a package
Since the package was installed on your default python enviroment you can simply import it as `import cgdat`.

# License
This tool is licensed under the GPL open source license. You are therefore free use the source code in any way provided that you the original copyright statements.

# Contributors
* [rickstaa](https://github.com/rickstaa)

# Credits
* CDAT icon created by FreePis from [www.flaticon.com](https://www.flaticon.com)